import{cw as r}from"./outputWidgets.3eae54a8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="29d55743-a4b3-405d-bb6e-25daf02ac540",e._sentryDebugIdIdentifier="sentry-dbid-29d55743-a4b3-405d-bb6e-25daf02ac540")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.eb34f885.js.map
