import{a as e,A as a,B as i}from"./Text.6e609d9b.js";import{A as o}from"./Link.6752ae01.js";import{a as r,A as d}from"./Title.ee79f8a8.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="fed2e6db-12cc-47cb-9d2b-f9bc06e35663",n._sentryDebugIdIdentifier="sentry-dbid-fed2e6db-12cc-47cb-9d2b-f9bc06e35663")}catch{}})();e.Text=a;e.Title=r;e.Paragraph=d;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,d),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.a1146823.js.map
