import{_ as m}from"./Sidebar.vue_vue_type_script_setup_true_lang.67d6c17f.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.7b75af0d.js";import{F as l,G as u,H as d}from"./icons.e8458af4.js";import{d as b,eB as f,G as _,a as g,b as y,c as v,w as t,f as r}from"./outputWidgets.3eae54a8.js";import{a as w}from"./asyncComputed.951244d5.js";import"./authorManager.8abbaff3.js";import"./index.5a75491f.js";import{O as z}from"./organization.e4c807bd.js";import{B as h}from"./BaseLayout.b90c6103.js";import"./index.3d7ce90e.js";import"./logo.084e5d7c.js";import"./Text.6e609d9b.js";import"./index.6ffcef0e.js";import"./index.cf4c23b9.js";import"./record.a0b21aff.js";import"./pubsub.4b1da012.js";import"./gateway.350ede4a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9acf2722-4164-4821-a09c-2ec643c4745b",e._sentryDebugIdIdentifier="sentry-dbid-9acf2722-4164-4821-a09c-2ec643c4745b")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=_(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:d,path:"billing",unavailable:!0}]}];return(I,B)=>{const c=g("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(m,{class:"sidebar",sections:s})]),content:t(()=>[r(c)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.54d2dad0.js.map
