import{T as e,A as d}from"./TabPane.a69e4170.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="475d1aba-bc6d-4fc2-a205-c1bd866b17c2",n._sentryDebugIdIdentifier="sentry-dbid-475d1aba-bc6d-4fc2-a205-c1bd866b17c2")}catch{}})();e.TabPane=d;e.install=function(n){return n.component(e.name,e),n.component(d.name,d),n};
//# sourceMappingURL=index.cb7d4f9e.js.map
