import"./outputWidgets.3eae54a8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="53f205bf-25fc-4bc1-859a-17e994149737",e._sentryDebugIdIdentifier="sentry-dbid-53f205bf-25fc-4bc1-859a-17e994149737")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}};export{f as i};
//# sourceMappingURL=url.0fe4f7e9.js.map
