import{d as k,eB as B,eA as I,G as w,a as h,b as o,c as d,w as a,eK as j,f as n,u as t,ev as l,eC as x,aq as g,eD as z,bq as C,ex as A,bg as D,cC as S}from"./outputWidgets.3eae54a8.js";import{B as $}from"./BaseLayout.b90c6103.js";import{a as M}from"./asyncComputed.951244d5.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.6aa0dde9.js";import"./authorManager.8abbaff3.js";import{a as P}from"./build.2a9d7e64.js";import"./index.5a75491f.js";import{P as R}from"./project.7a2f8853.js";import{O as V}from"./organization.e4c807bd.js";import{B as q,a as E,c as L}from"./index.6ffcef0e.js";import{A as O}from"./Text.6e609d9b.js";import"./gateway.350ede4a.js";import"./WarningFilled.d99917ef.js";import"./log.1f3341e9.js";import"./ant-design.8edb4f18.js";import"./index.429b3954.js";import"./Title.ee79f8a8.js";import"./index.9d362493.js";import"./Link.6752ae01.js";import"./index.89d7b0fc.js";import"./TabPane.a69e4170.js";import"./hasIn.d5bc6fc2.js";import"./index.5561ea1c.js";import"./isNumeric.75337b1e.js";import"./icons.e8458af4.js";import"./index.b9422562.js";import"./FormItem.8edd4e05.js";import"./index.cf4c23b9.js";import"./record.a0b21aff.js";import"./pubsub.4b1da012.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="bc225370-25c7-4993-8ba3-b23730b2b18d",i._sentryDebugIdIdentifier="sentry-dbid-bc225370-25c7-4993-8ba3-b23730b2b18d")}catch{}})();const T={key:0},F={key:2},kt=k({__name:"Build",setup(i){const s=B(),c=I(),m=s.params.buildId,{result:e,loading:b}=M(async()=>{const r=await P.get(m),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),f=w(()=>!b.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&c.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return o(),d($,null,{navbar:a(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:a(()=>[f.value?(o(),d(t(q),{key:0},{default:a(()=>[(o(!0),l(C,null,x(f.value,(_,v)=>(o(),d(t(E),{key:v},{default:a(()=>[n(u,{to:_.path},{default:a(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):A("",!0)]),_:1})]),content:a(()=>[t(b)?(o(),l("div",T,[n(t(D))])):t(e)?(o(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(o(),l("div",F,[n(t(S),{direction:"vertical"},{default:a(()=>[n(t(O),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{kt as default};
//# sourceMappingURL=Build.40f66e3c.js.map
