import{C as t,E as d,K as i,a as c,M as l,c as y,P as f,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.d6413649.js";import"./outputWidgets.3eae54a8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4e6925d1-9610-493c-a11d-1b77a8510a7a",e._sentryDebugIdIdentifier="sentry-dbid-4e6925d1-9610-493c-a11d-1b77a8510a7a")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,l as MarkerSeverity,y as MarkerTag,f as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.74907718.js.map
