import{v as t,b as s,ev as d}from"./outputWidgets.3eae54a8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ff2a05a5-25dd-4eeb-bcfe-215307949fdc",e._sentryDebugIdIdentifier="sentry-dbid-ff2a05a5-25dd-4eeb-bcfe-215307949fdc")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const c=t(o,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.45b9a22a.js.map
