import{d,eB as b,G as p,a as g,b as f,c as v,w as r,f as s}from"./outputWidgets.3eae54a8.js";import{B as _}from"./BaseLayout.b90c6103.js";import{a as h}from"./asyncComputed.951244d5.js";import"./authorManager.8abbaff3.js";import"./index.5a75491f.js";import{P as z}from"./project.7a2f8853.js";import{O as y}from"./organization.e4c807bd.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.7b75af0d.js";import{_ as I}from"./Sidebar.vue_vue_type_script_setup_true_lang.67d6c17f.js";import{e as w,J as O,K as C,L as B,M as $,N as k,q as L,O as P,s as M,F as N,G as x,H as D}from"./icons.e8458af4.js";import"./index.cf4c23b9.js";import"./record.a0b21aff.js";import"./pubsub.4b1da012.js";import"./gateway.350ede4a.js";import"./logo.084e5d7c.js";import"./Text.6e609d9b.js";import"./index.6ffcef0e.js";import"./index.3d7ce90e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="ff534a6a-3bcf-4d37-933d-b3e9be9a1476",o._sentryDebugIdIdentifier="sentry-dbid-ff534a6a-3bcf-4d37-933d-b3e9be9a1476")}catch{}})();const aa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=p(()=>{var e,t,n,l;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(l=a.value)==null?void 0:l.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=p(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:$},{name:"Env Vars",path:"env-vars",icon:k},{name:"Files",path:"files",icon:L},{name:"Logs",icon:P,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:N,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:x,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:D,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{aa as default};
//# sourceMappingURL=Project.edbe45e0.js.map
